
/*
 * This program allows the user to calibrate the analog sensor by 
 * opening the Serial Monitor and looking at the range of values
 * you're getting back from that sensor. You can then update the
 * values in the "map" function to extend (interpolate) the values
 * that you're getting to the full 0-179 range of the servo. 
 * 
 * After you look at the actual range of the sensor values using the 
 * Serial Monitor, replace the low and high values in the "map" 
 * statement and re-load the program. You should then get the max
 * range of motion for your servo. 
 */
 
#include <Servo.h> 
Servo myservo;        // create servo object to control a servo 
int sensorPin = A0;   // analog pin used to connect the potentiometer
int servoPin = 9;     // the pin the servo control is connected to

int sensorVal;        // variable to read the value from the analog pin 
int scaledVal;        // variable to hold the mapped and constrained value

void setup() { 
  myservo.attach(servoPin);  // attaches the servo object control wire 
  Serial.begin(9600); // init the serial port at 9600 baud 
} 

void loop() { 
  sensorVal = analogRead(sensorPin); // read the value of the sensor
  // Here's where you can modify the expected sensor value
  // The default is the full 0-1023 range, but your sensor may return
  // values in a much more restricted range. 
  // You can also modify the output range. The default is the full servo range
  // of 0 to 179. But, you might want to restrict the servo to a more limited 
  // range.
  // Note that for a "continuous rotation" servo, it should be stopped
  // at a value around 90. Greater values will spin faster in one direction
  // and lesser values will spin faster in the other direction. 
  scaledVal = map(sensorVal, 0, 1023, 0, 179);  // scale it to use it with the servo
  // If you modify the output range, you should also update things here
  // so that the "scaledVal" is constrained to the right numbers. 
  scaledVal = constrain(scaledVal, 0, 179);    // make sure it stays in range
  
  Serial.print("sensor = " );   // This print section is used for calibration   
  Serial.print(sensorVal);      // Write down the values you see from the sensor
  Serial.print("\t output = "); // and replace the “0, 1023” above with the 
  Serial.println(scaledVal);    // range of values you actually see
  
  myservo.write(scaledVal);   // sets the servo position according to the scaled value
  delay(20);                  // wait for the servo to get there 
} 

